﻿using CollaborativePlatformMain.DFEntity;
using CollaborativePlatformMain.DFEntity.MessageSubUtil;
using CollaborativePlatformMain.Form.MessageSubPage.Project;
using CollaborativePlatformMain.Form.UserControlForm;
using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Shapes;

namespace CollaborativePlatformMain.Form
{
    /// <summary>
    /// UploadDrawingForm.xaml 的交互逻辑
    /// </summary>
    public partial class UploadDrawingForm : Window
    {
        /// <summary>
        /// 父级窗体
        /// </summary>
        public OperatingFloorPage OperatingFloorPage;


        /// <summary>
        /// 是否为更新图纸
        /// </summary>
        public bool IsRenew = false;

        /// <summary>
        /// 更新、上传图纸
        /// </summary>
        /// <param name="isRenew"></param>
        public UploadDrawingForm(OperatingFloorPage operatingFloorPage, bool isRenew)
        {
            InitializeComponent();
            OperatingFloorPage = operatingFloorPage;
            IsRenew = isRenew;
        }


        /// <summary>
        /// 窗体初始化
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void Window_Loaded(object sender, RoutedEventArgs e)
        {
            if (IsRenew)
            {
                sp_duibi.Visibility = Visibility.Visible;
            }


            #region 对比版本

            ObservableCollection<OperatEntity> operatEntities = OperatingFloorPage.ArchOperaDatas;
            //版本号
            List<string> versions = new List<string>();
            foreach (var operatEntity in operatEntities)
            {
                versions.AddRange(operatEntity.SubDatas.Select(x => x.Node));
            }
            cb_dwgName.ItemsSource = null;
            cb_dwgName.ItemsSource = versions;


            #endregion

        }

        /// <summary>
        /// 单选框点击事件
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void ButtonBase_OnClick(object sender, RoutedEventArgs e)
        {
            RadioButton radioButton = sender as RadioButton;

            if (radioButton.Content.Equals("是"))
            {
                sp_contrast.Visibility = Visibility.Visible;
            }
            else
            {
                sp_contrast.Visibility = Visibility.Collapsed;
            }

        }

        /// <summary>
        /// 上传图纸
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void Button_Click(object sender, RoutedEventArgs e)
        {
            //List<OperatEntity> operatEntities = OperatingFloorPage.AllOperatDatas;

            SetOPerData(ArchLayerDatas, ref OperatingFloorPage.ArchOperaDatas);
            SetOPerData(WarmLayerDatas, ref OperatingFloorPage.WarmOperaDatas);

            //更新数据
            OperatingFloorPage.ReplaceData();


            this.Close();
        }

        /// <summary>
        /// 更换数据
        /// </summary>
        /// <param name="floorLayerDatas"></param>
        /// <param name="operatEntities"></param>
        public void SetOPerData(List<FloorLayerData> floorLayerDatas, ref ObservableCollection<OperatEntity> operatEntities)
        {

            //二级
            ObservableCollection<OperatEntity> twoDatas = new ObservableCollection<OperatEntity>();
            twoDatas.Add(new OperatEntity("原图纸", "", new ObservableCollection<OperatEntity>(), false));

            //对比图
            if (IsRenew)
            {
                //对比版本
                string banben = cb_dwgName.SelectedItem as string;

                //选择的对比范围
                List<NativeDataInfo> selNativeDatas = cb_floor.ItemsSource.Where(x => x.IsSelect).ToList();

                ObservableCollection<OperatEntity> duibiDatas = new ObservableCollection<OperatEntity>();
                foreach (var nativeDataInfo in selNativeDatas)
                {
                    duibiDatas.Add(new OperatEntity(nativeDataInfo.Name, "", new ObservableCollection<OperatEntity>(), false));
                }
                twoDatas.Add(new OperatEntity("对比图-" + banben, "", duibiDatas, false));
            }

            //三级
            ObservableCollection<OperatEntity> threeDatas = new ObservableCollection<OperatEntity>();
            threeDatas.Add(new OperatEntity("整栋图", "", new ObservableCollection<OperatEntity>(), false));

            //四级
            ObservableCollection<OperatEntity> fourDatas = new ObservableCollection<OperatEntity>();
            foreach (var floorLayerData in floorLayerDatas)
            {
                //五级
                ObservableCollection<OperatEntity> fiveDatas = new ObservableCollection<OperatEntity>();

                List<FloorLayerData> layersDatas = floorLayerData.SubDatas;
                foreach (var layerData in layersDatas)
                {
                    fiveDatas.Add(new OperatEntity(layerData.LayerName, "", new ObservableCollection<OperatEntity>(), true));
                }

                fourDatas.Add(new OperatEntity(floorLayerData.FloorName, "", fiveDatas, false));
            }
            threeDatas.Add(new OperatEntity("分层图", "", fourDatas, false));
            twoDatas.Add(new OperatEntity("治理图纸", "", threeDatas, false));

            OperatEntity firstData = new OperatEntity(tb_dwgName.Text.ToString(), "", twoDatas, false);

            //添加数据
            foreach (var operatEntity in operatEntities)
            {
                operatEntity.SubDatas.Add(firstData);
                break;
            }

        }

        /// <summary>
        /// 窗体数据
        /// </summary>
        public List<FloorLayerData> ArchLayerDatas = new List<FloorLayerData>();
        public List<FloorLayerData> StruLayerDatas = new List<FloorLayerData>();
        public List<FloorLayerData> WaterLayerDatas = new List<FloorLayerData>();
        public List<FloorLayerData> WarmLayerDatas = new List<FloorLayerData>();
        public List<FloorLayerData> EleLayerDatas = new List<FloorLayerData>();

        /// <summary>
        /// 选择图纸
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void bt_xaunze_Click(object sender, RoutedEventArgs e)
        {
            FloorDrawingForm floorDrawingForm = new FloorDrawingForm(this);
            floorDrawingForm.Show();

            this.Hide();
        }


        /// <summary>
        /// 对比版本改变事件
        /// 目的：实时刷新对比范围
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void cb_dwgName_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            //选中的对比版本
            string selValue = cb_dwgName.SelectedItem.ToString();

            //对比范围
            List<string> floorValues = new List<string>();

            bool isBreak = false;
            ObservableCollection<OperatEntity> operatEntities = OperatingFloorPage.ArchOperaDatas;
            foreach (var operatEntity in operatEntities)
            {
                //版本号
                foreach (var twoData in operatEntity.SubDatas)
                {
                    if (twoData.Node == selValue)
                    {
                        //原图、对比图、治理图
                        foreach (var threeData in twoData.SubDatas)
                        {
                            if (threeData.Node.Contains("治理"))
                            {
                                //整栋图、分层图
                                foreach (var fourData in threeData.SubDatas)
                                {
                                    if (fourData.Node.Contains("分层"))
                                    {
                                        foreach (var fiveData in fourData.SubDatas)
                                        {
                                            floorValues.Add(fiveData.Node);
                                        }
                                    }
                                }
                            }
                        }

                        isBreak = true;
                        break;
                    }
                }
                if (isBreak) break;
            }

            //赋值
            List<NativeDataInfo> nativeDataInfos = new List<NativeDataInfo>();
            foreach (var floorValue in floorValues)
            {
                nativeDataInfos.Add(new NativeDataInfo(Guid.NewGuid().ToString(), floorValue));
            }
            cb_floor.ItemsSource = nativeDataInfos;

        }
    }
}
